
/*

purpose: placebo test on 12 subjects who did identify as AAM

input: 
1) "$drive/3output_data/oakland_analysis_lenient.dta" -- includes non-AAM subjects
2) "$drive/3output_data/oakland_analysis_final.dta" -- to randomly select 12 in-sample subjects


output: 
1) "$drive\3output_data\reps12_pshare_invasive" - post share bootstrap data
2) "$drive\3output_data\reps12_dshare_invasive" - delta share bootstrap data
3) figure6_post.pdf
4) figure6_delta.pdf
		
author: MF 

date:  6.4.18
updated 7.12.19 to change numbering 

*/

clear
set more off 

log using "$drive\4log\figure6_placebo.smcl", replace



***********************
 *POST SHARE INVASIVE*
***********************

*regressions for non-black subjects
use "$drive\3output_data\oakland_analysis_lenient.dta", clear

		drop if attrit ==  1 | women == 1
		
*limit to same set of doctors who saw 12 non-AfAm patients 
		keep if (doctor_id == "BL3" | doctor_id == "BL4" | doctor_id == "BL5" | doctor_id == "NB1" | ///
				 doctor_id == "NB3" | doctor_id == "NB4" | doctor_id == "NB7" | doctor_id == "NB8") 
		
*obtain estimates from non-AfAm	
		reg post_shr_invasive black_dr if tag == 1 & black_resp != 1	
			local est1 = _b[black_dr] /*-.2*/	
	
*bootstrap with sample size of 12 
	use "$drive\3output_data\oakland_analysis_final.dta", clear
		keep if tag == 1
		local reps 1000 
		set seed 3950267
		keep if (doctor_id == "BL3" | doctor_id == "BL4" | doctor_id == "BL5" | doctor_id == "NB1" | ///
				 doctor_id == "NB3" | doctor_id == "NB4" | doctor_id == "NB7" | doctor_id == "NB8") 
				 
		bootstrap  _b[black_dr], size(12) reps(`reps') saving("$drive\3output_data\reps12_pshare_invasive", replace): reg post_shr_invasive black_dr if tag == 1, r 
		

		use "$drive\3output_data\reps12_pshare_invasive", clear

		twoway hist _bs_1, xtitle("Coefficient") percent bin(25) color(gs12%50) || ///
			   scatteri 0 `est1' 15 `est1', c(l) m(i) color("188 0 44"%50) plotregion(margin(b=0))  ///
			   text(14.5 -.19 "Non-Criteria Sample, <97%", place(e) color("188 0 44")) ///
				ytitle("") yscale(r(0 15)) ylabel(0 "0"  5 "5" 10 "10" 15 "15%", angle(0)) legend(off) ///
				xscale(r(-1.2 1.2)) xlabel(-1.2(.3)1.2)			
		graph export "$drive/5figures/figure6_post.pdf", replace 	
		
		dis `est1' 
		count if _b < `est1'
		local num = r(N) 
		dis `num'/`reps'  /*.032*/
		
		
		
************************
 *DELTA SHARE INVASIVE*
************************
		
*regressions for non-black subjects
use "$drive\3output_data\oakland_analysis_lenient.dta", clear

		drop if attrit ==  1 | women == 1
		
*limit to same set of doctors who saw 12 non-AfAm patients 
		keep if (doctor_id == "BL3" | doctor_id == "BL4" | doctor_id == "BL5" | doctor_id == "NB1" | ///
				 doctor_id == "NB3" | doctor_id == "NB4" | doctor_id == "NB7" | doctor_id == "NB8") 
		
*obtain estimates from non-AfAm	
		reg delta_shr_invasive black_dr if tag == 1 & black_resp != 1	
			local est1 = _b[black_dr] /*-.047*/	
	
*bootstrap with sample size of 12 
	use "$drive\3output_data\oakland_analysis_final.dta", clear
		keep if tag == 1
		local reps 1000 
		set seed 3950267
		keep if (doctor_id == "BL3" | doctor_id == "BL4" | doctor_id == "BL5" | doctor_id == "NB1" | ///
				 doctor_id == "NB3" | doctor_id == "NB4" | doctor_id == "NB7" | doctor_id == "NB8") 
				 
		bootstrap  _b[black_dr], size(12) reps(`reps') saving("$drive\3output_data\reps12_dshare_invasive", replace): reg delta_shr_invasive black_dr if tag == 1, r 
		

		use "$drive\3output_data\reps12_dshare_invasive", clear

		twoway hist _bs_1, xtitle("Coefficient") percent bin(25) color(gs12%50) || ///
			   scatteri 0 `est1' 15 `est1', c(l) m(i) color("188 0 44") plotregion(margin(b=0))  ///
			   text(14.5 -.051 "Non-Criteria Sample, <89%", place(e) color("188 0 44")) ///
				ytitle("") yscale(r(0 15)) ylabel(0 "0"  5 "5" 10 "10" 15 "15%", angle(0)) legend(off) ///
				xscale(r(-1.2 1.2)) xlabel(-1.2(.3)1.2)			
		graph export "$drive/5figures/figure6_delta.pdf", replace 	
		
		dis `est1' 
		count if _b < `est1'
		local num = r(N) 
		dis `num'/`reps'  /*.108*/		

log close	
