/*
date: 5.15.2018

purpose: histgrams of test values by MD race
		
input:	"$drive\3output_data\oakland_analysis_final.dta"

output:
1) "$drive\5figures\figure7_systolic.pdf"
2) "$drive\5figures\figure7_bmi.pdf"
3) "$drive\5figures\figure7_cho.pdf"
4) "$drive\5figures\figure7_dia.pdf"
 
author: MF

*/


clear
set more off 

log using "$drive\4log\figure7_values.smcl", replace


use "$drive\3output_data\oakland_analysis_final.dta", clear


*Blood Pressure
	twoway (histogram value_systolic if black_dr == 0,  xtitle("Systolic Blood Pressure (mm Hg)") percent start(90) width(10) color(gs12)) ///
		   (histogram value_systolic if black_dr == 1, percent start(90) width(10) color(ebblue%40)), ///
		   legend(order(1 "Non-Black Doctor" 2 "Black Doctor")) plotregion(margin(b=0)) ///
		   xline(120, lpattern(shortdash) lcolor(gs12))  xline(140, lpattern(shortdash) lcolor(gs12))  xline(180, lpattern(shortdash) lcolor(gs12)) ///
		   text(50 121 "Pre-Hyp.", color(gs8) place(e) size(small)) text(50 141 "Hypertension", color(gs8) place(e) size(small)) ///
		   text(50 181 "Hypertensive Crisis", color(gs8) place(e) size(small)) ///   
		   ytitle("") yscale(r(0 60)) ylabel(0 "0"  20 "20" 40 "40" 60 "60%", angle(0))
		   graph export "$drive\5figures\figure7_systolic.pdf", replace	   

*Body Mass Index		   
	twoway (histogram value_bmi if black_dr == 0,  xtitle("BMI (kg/m{superscript:2})") start(15) width(5) percent color(gs12)) ///
		   (histogram value_bmi if black_dr == 1, percent start(15) width(5) color(ebblue%40)), ///
		   legend(order(1 "Non-Black Doctor" 2 "Black Doctor")) plotregion(margin(b=0)) ///
		   xline(25, lpattern(shortdash) lcolor(gs12))  xline(30, lpattern(shortdash) lcolor(gs12)) ///		   
		   text(55 25.3 "Overweight", color(gs8) place(e) size(small)) text(45 30.4 "Obese", color(gs8) place(e) size(small)) ///	   
		   ytitle("") yscale(r(0 60)) ylabel(0 "0"  20 "20" 40 "40" 60 "60%", angle(0))  xscale(r(10 60)) xlabel(10(10)60) 
		   graph export "$drive\5figures\figure7_bmi.pdf", replace	   
	   
*Cholesterol	
preserve	   
	twoway (histogram value_cho if black_dr == 0,  xtitle("Total Cholesterol (mg/dL)") start(100) width(50) percent color(gs12)) ///
		   (histogram value_cho if black_dr == 1, percent start(100) width(50) color(ebblue%40)), ///
		   legend(order(1 "Non-Black Doctor" 2 "Black Doctor")) plotregion(margin(b=0)) ///
		   ytitle("") yscale(r(0 60)) ylabel(0 "0"  20 "20" 40 "40" 60 "60%", angle(0)) ///
   		   xline(200, lpattern(shortdash) lcolor(gs12)) xscale(r(100 400)) xlabel(100(50)400) ///		   
		   text(50 202 "High Choletserol", color(gs8) place(e) size(small))
		   graph export "$drive\5figures\figure7_cho.pdf", replace	   
restore 
		   
*Diabetes		  
preserve 
	twoway (histogram value_dia if black_dr == 0,  xtitle("Hemoglobin A1c (%)") start(4) width(.5) percent color(gs12)) ///
		   (histogram value_dia if black_dr == 1, percent start(4) width(.5) color(ebblue%40)), ///
		   legend(order(1 "Non-Black Doctor" 2 "Black Doctor")) plotregion(margin(b=0)) ///
		   ytitle("") yscale(r(0 60)) ylabel(0 "0"  20 "20" 40 "40" 60 "60%", angle(0)) ///				   
		   xline(5.7, lpattern(shortdash) lcolor(gs12))  xline(6.4, lpattern(shortdash) lcolor(gs12))  ///		   
		   text(55 5.72 "Pre-diabetes", color(gs8) place(e) size(small))  text(45 6.45 "Diabetes", color(gs8) place(e) size(small))
		   graph export "$drive\5figures\figure7_dia.pdf", replace	  		   
	restore 		
	
log close	
