
/*
date: 4.29.2019

purpose: joint test of invasives and invasives vs. non-invasives 
	
input: 
1) "$drive\3output_data\oakland_analysis_final.dta"
2) "$drive\3output_data\race_combinations_6black.dta" - RI permutations of black dr

output: 
1) "$drive\6tables\table4_Ftest.csv"
2) Permutation datasets for each stage
	- "$drive\3output_data\Ftestpre6black.dta"
	- "$drive\3output_data\Ftestpost6black.dta"
	- "$drive\3output_data\Ftestdelta6black.dta"

author: MA/MF 

*/

clear all
set more off 
cap log close 
set maxvar 20000

log using "$drive\4log\table4_Ftest.smcl", replace


use "$drive\3output_data\oakland_analysis_final.dta", clear

*merge in 3003 14 choose 6 doctor race combinations  
	merge m:1 doctor_id using "$drive\3output_data\race_combinations_6black.dta"

*permutation reps - loop over pre/post/delta binary test take-up outcomes (subject-test panel) 
	foreach x in pre post delta { 	
		capture erase `"$drive\3output_data\Ftest`x'6black.dta"'		
		forvalues i = 1(1)3003 { 	
			foreach var in  bp_test bmi_test dia_test cho_test flu_test {
				cap drop p_`var'
				gen p_`var' = black_dr`i'* `var' 
			}	
			preserve
				qui reg `x'ind_test  bmi_test cho_test dia_test flu_test p_bp p_bmi p_cho p_dia p_flu_test sl5 sl10, cluster(doctor_id)
					test (p_cho_test = 0) (p_dia_test = 0) (p_flu_test = 0)   // test all invasives = 0 
					gen Ftest_inv`x' = r(F)
					test (p_bp_test + p_bmi_test) = (p_cho_test + p_dia_test + p_flu_test) // test sum noninvasive = sum invasives 
					gen Ftest_noninv`x'= r(F)				
					keep Ftest_inv Ftest_noninv
					keep if _n ==1
					dis `i' 
					capture append using `"$drive\3output_data\Ftest`x'6black.dta"'
					save `"$drive\3output_data\Ftest`x'6black.dta"', replace
			restore	
		}
	}

*study sample 
	foreach x in pre post delta { 
		reg `x'ind_test  bmi_test cho_test dia_test flu_test bl_bp bl_bmi bl_cho bl_dia bl_flu_test sl5 sl10, cluster(doctor_id)
			est store A`x'
			test (bl_cho_test = 0) (bl_dia_test = 0) (bl_flu_test = 0)   // test all invasives = 0 
				global tFtest_inv`x'  = r(F)
				estadd scalar iFtest = r(F)				
			test (bl_bp_test + bl_bmi_test) = (bl_cho_test + bl_dia_test + bl_flu_test) // test sum noninvasive = sum invasives 
				global tFtest_noninv`x' = r(F)
				estadd scalar nFtest = r(F)
	}
	
		foreach x in pre post delta { 	
			use `"$drive\3output_data\Ftest`x'6black.dta"', clear
			local reps = 3003 
				count if Ftest_inv`x' > ${tFtest_inv`x'} 
					local p = r(N) 
					est restore A`x'					
					estadd scalar p_val_inv =  `p' / `reps'	
				count if Ftest_noninv`x' > ${tFtest_noninv`x'}
					local p = r(N)
					est restore A`x'
					estadd scalar p_val_noninv =  `p' / `reps'					
		}
	
			esttab _all using "$drive\6tables\table4_Ftest.csv", drop(_cons sl5 sl10) ///
						se b(3) stats(iFtest nFtest p_val_inv p_val_noninv N) nostar replace 		

	log close 
	
	
